@@ -144,9 +144,9 @@ void mergeAnchoredDfas(vector<unique_ptr<raw_dfa>> &dfas,
     for (auto &rdfa : dfas) {
         u32 start_size = mcclellanStartReachSize(rdfa.get());
         if (start_size <= MAX_SMALL_START_REACH) {
-            small_starts.emplace_back(move(rdfa));
+            small_starts.emplace_back(std::move(rdfa));
         } else {
-            big_starts.emplace_back(move(rdfa));
+            big_starts.emplace_back(std::move(rdfa));
         }
     }
     dfas.clear();
@@ -158,10 +158,10 @@ void mergeAnchoredDfas(vector<unique_ptr<raw_dfa>> &dfas,
 
     // Rehome our groups into one vector.
     for (auto &rdfa : small_starts) {
-        dfas.emplace_back(move(rdfa));
+        dfas.emplace_back(std::move(rdfa));
     }
     for (auto &rdfa : big_starts) {
-        dfas.emplace_back(move(rdfa));
+        dfas.emplace_back(std::move(rdfa));
     }
 
     // Final test: if we've built two DFAs here that are small enough, we can
@@ -685,7 +685,7 @@ int finalise_out(RoseBuildImpl &build, const NGHolder &h,
     if (check_dupe(*out_dfa, build.anchored_nfas[hash], remap)) {
         return ANCHORED_REMAP;
     }
-    build.anchored_nfas[hash].emplace_back(move(out_dfa));
+    build.anchored_nfas[hash].emplace_back(std::move(out_dfa));
     return ANCHORED_SUCCESS;
 }
 
@@ -700,7 +700,7 @@ int addAutomaton(RoseBuildImpl &build, const NGHolder &h, ReportID *remap) {
 
     auto out_dfa = std::make_unique<raw_dfa>(NFA_OUTFIX_RAW);
     if (determinise(autom, out_dfa->states, MAX_DFA_STATES)) {
-        return finalise_out(build, h, autom, move(out_dfa), remap);
+        return finalise_out(build, h, autom, std::move(out_dfa), remap);
     }
 
     DEBUG_PRINTF("determinise failed\n");
@@ -767,7 +767,7 @@ void buildSimpleDfas(const RoseBuildImpl &build, const vector<u32> &frag_map,
         rdfa->start_floating = DEAD_STATE;
         rdfa->alpha_size = autom.alphasize;
         rdfa->alpha_remap = autom.alpha;
-        anchored_dfas->emplace_back(move(rdfa));
+        anchored_dfas->emplace_back(std::move(rdfa));
     }
 }
 
@@ -784,7 +784,7 @@ vector<unique_ptr<raw_dfa>> getAnchoredDfas(RoseBuildImpl &build,
     // DFAs that already exist as raw_dfas.
     for (auto &anch_dfas : build.anchored_nfas) {
         for (auto &rdfa : anch_dfas.second) {
-            dfas.emplace_back(move(rdfa));
+            dfas.emplace_back(std::move(rdfa));
         }
     }
     build.anchored_nfas.clear();
@@ -834,7 +834,7 @@ size_t buildNfas(vector<raw_dfa> &anchored_dfas,
 
         assert(nfa->length);
         total_size += ROUNDUP_CL(sizeof(anchored_matcher_info) + nfa->length);
-        nfas->emplace_back(move(nfa));
+        nfas->emplace_back(std::move(nfa));
     }
 
     // We no longer need to keep the raw_dfa structures around.
@@ -861,7 +861,7 @@ vector<raw_dfa> buildAnchoredDfas(RoseBuildImpl &build,
     dfas.reserve(anch_dfas.size());
     for (auto &rdfa : anch_dfas) {
         assert(rdfa);
-        dfas.emplace_back(move(*rdfa));
+        dfas.emplace_back(std::move(*rdfa));
     }
     return dfas;
 }
