@@ -738,7 +738,7 @@ void addFragmentLiteral(const RoseBuildImpl &build, MatcherProto &mp,
 
     const auto &groups = f.groups;
 
-    mp.lits.emplace_back(move(s_final), nocase, noruns, f.fragment_id,
+    mp.lits.emplace_back(std::move(s_final), nocase, noruns, f.fragment_id,
                          groups, msk, cmp);
 }
 
@@ -936,7 +936,7 @@ buildFloatingMatcherProto(const RoseBuildImpl &build,
         throw CompileError("Unable to generate literal matcher proto.");
      }
 
-     return std::make_unique<LitProto>(move(proto), mp.accel_lits);
+     return std::make_unique<LitProto>(std::move(proto), mp.accel_lits);
 }
 
 unique_ptr<LitProto>
@@ -964,7 +964,7 @@ buildDelayRebuildMatcherProto(const RoseBuildImpl &build,
         throw CompileError("Unable to generate literal matcher proto.");
     }
 
-    return std::make_unique<LitProto>(move(proto), mp.accel_lits);
+    return std::make_unique<LitProto>(std::move(proto), mp.accel_lits);
 }
 
 unique_ptr<LitProto>
@@ -1021,7 +1021,7 @@ buildSmallBlockMatcherProto(const RoseBuildImpl &build,
         throw CompileError("Unable to generate literal matcher proto.");
     }
 
-    return std::make_unique<LitProto>(move(proto), mp.accel_lits);
+    return std::make_unique<LitProto>(std::move(proto), mp.accel_lits);
 }
 
 unique_ptr<LitProto>
@@ -1046,7 +1046,7 @@ buildEodAnchoredMatcherProto(const RoseBuildImpl &build,
         throw CompileError("Unable to generate literal matcher proto.");
     }
 
-    return std::make_unique<LitProto>(move(proto), mp.accel_lits);
+    return std::make_unique<LitProto>(std::move(proto), mp.accel_lits);
 }
 
 } // namespace ue2
